@@ -8,7 +8,7 @@
 #' @param order integer; Number of partial moment quadrants to be generated.  \code{(order = "max")} will institute a perfect fit.
 #' @param obs.req integer; (8 default) Required observations per cluster where quadrants will not be further partitioned if observations are not greater than the entered value.  Reduces minimum number of necessary observations in a quadrant to 1 when \code{(obs.req = 1)}.
 #' @param min.obs.stop logical; \code{TRUE} (default) Stopping condition where quadrants will not be further partitioned if a single cluster contains less than the entered value of \code{obs.req}.
-#' @param noise.reduction the method of determing regression points options: ("mean", "median", "mode", "off"); \code{(noise.reduction = "median")} uses medians instead of means for partitions, while \code{(noise.reduction = "mode")} uses modes instead of means for partitions.  Defaults to \code{(noise.reduction = "mean")}, while \code{(noise.reduction = "off")} will partition quadrant to a single observation for a given \code{(order = ...)}.
+#' @param noise.reduction the method of determing regression points options: ("mean", "median", "mode", "off"); \code{(noise.reduction = "mean")} uses means for partitions.  \code{(noise.reduction = "median")} uses medians instead of means for partitions, while \code{(noise.reduction = "mode")} uses modes instead of means for partitions.  Defaults to \code{(noise.reduction = "off")} where an overall central tendency measure is used.
 #' @return Returns:
 #'  \itemize{
 #'   \item{\code{"dt"}} a \link{data.table} of \code{x} and \code{y} observations with their partition assignment \code{"quadrant"} in the 3rd column and their prior partition assignment \code{"prior.quadrant"} in the 4th column.
@@ -45,36 +45,38 @@ NNS.part = function(x, y,
                     order = NULL,
                     obs.req = 8,
                     min.obs.stop = TRUE,
-                    noise.reduction = "mean"){
+                    noise.reduction = "off"){
 
     noise.reduction <- tolower(noise.reduction)
     if (!any(noise.reduction %in% c("mean", "median", "mode",
                                     "off"))) {
         stop("Please ensure noise.reduction is from 'mean', 'median', 'mode' or 'off'")
     }
-    if (is.null(obs.req))
-        obs.req <- 8
+    if (is.null(obs.req)) obs.req <- 8
+
     if (!is.null(order)) {
         if (order == 0) {
             order <- 1
-        }
-        else {
+        } else {
             order <- order
         }
+    } else {
+        order <- Inf
     }
-    else {
-        order = Inf
-    }
+
     if (Voronoi) {
         x.label <- deparse(substitute(x))
         y.label <- deparse(substitute(y))
     }
+
     x <- as.numeric(x)
     y <- as.numeric(y)
+
     if (length(x) < 8) {
         order <- 1
         obs.req <- 0
     }
+
     PART <- data.table(x, y, quadrant = "q", prior.quadrant = "pq")[, `:=`(counts, .N), by = "quadrant"][, `:=`(old.counts, .N), by = "prior.quadrant"]
 
     if(Voronoi) {
@@ -82,25 +84,20 @@ NNS.part = function(x, y,
     }
 
     if(!is.numeric(order)) {
-        obs.req <- 0
+        obs.req <- 1
         type <- type
-        hard.stop <- Inf
+        hard.stop <- max(ceiling(log(length(x), 2)), 1)
     } else {
         obs.req <- obs.req
         type <- type
         hard.stop <- max(floor(log(length(x), 2)), 1)
     }
 
-    if(noise.reduction == "off") {
-        obs.req <- 1
-    } else {
-        obs.req <- obs.req
-    }
 
     if(is.null(type)) {
         i <- 0L
         while (i >= 0) {
-            if(i == order | i == hard.stop) break
+            if(i == order || i == hard.stop) break
 
             PART[counts >= obs.req, `:=`(counts, .N), by = quadrant]
             PART[old.counts >= obs.req, `:=`(old.counts, .N), by = prior.quadrant]
@@ -113,11 +110,44 @@ NNS.part = function(x, y,
             obs.req.rows <- PART[counts >= obs.req, which = TRUE]
             old.obs.req.rows <- PART[old.counts >= obs.req, which = TRUE]
 
-            if(min.obs.stop & obs.req > 0 & length(obs.req.rows) < length(old.obs.req.rows)) break
+            if(min.obs.stop & obs.req > 0 & length(obs.req.rows) < length(old.obs.req.rows)) {print("here")
+                break
+            }
 
-            if(Voronoi) {
-                if(l.PART > obs.req) {
-                    if(noise.reduction == "mean" | noise.reduction == "off") {
+            if(noise.reduction == "off") {
+                if(Voronoi) {
+                    if(l.PART > obs.req) {
+                        PART[obs.req.rows, {
+                            segments(min(x), gravity(y), max(x), gravity(y),
+                                     lty = 3)
+                            segments(gravity(x), min(y), gravity(x), max(y),
+                                     lty = 3)
+                        }, by = quadrant]
+                    }
+                }
+
+                RP <- PART[obs.req.rows, lapply(.SD, gravity), by = quadrant, .SDcols = x:y]
+
+                RP[, `:=`(prior.quadrant, (quadrant))]
+
+                PART[obs.req.rows, `:=`(prior.quadrant, (quadrant))]
+
+                old.parts <- length(unique(PART$quadrant))
+
+                PART[RP, on = .(quadrant), `:=`(q_new, {
+                    lox = x.x <= i.x
+                    loy = x.y <= i.y
+                    1L + lox + loy * 2L
+                })]
+
+                PART[obs.req.rows, `:=`(quadrant, paste0(quadrant, q_new))]
+
+                new.parts <- length(unique(PART$quadrant))
+            }
+
+            if(noise.reduction == "mean") {
+                if(Voronoi) {
+                    if(l.PART > obs.req) {
                         PART[obs.req.rows, {
                             segments(min(x), mean(y), max(x), mean(y),
                                      lty = 3)
@@ -125,26 +155,8 @@ NNS.part = function(x, y,
                                      lty = 3)
                         }, by = quadrant]
                     }
-                    if(noise.reduction == "median") {
-                        PART[obs.req.rows, {
-                            segments(min(x), median(y), max(x), median(y),
-                                     lty = 3)
-                            segments(median(x), min(y), median(x),
-                                     max(y), lty = 3)
-                        }, by = quadrant]
-                    }
-                    if(noise.reduction == "mode") {
-                        PART[obs.req.rows, {
-                            segments(min(x), mode(y), max(x), mode(y),
-                                     lty = 3)
-                            segments(mode(x), min(y), mode(x), max(y),
-                                     lty = 3)
-                        }, by = quadrant]
-                    }
                 }
-            }
 
-            if(noise.reduction == "mean" | noise.reduction == "off") {
                 RP <- PART[obs.req.rows, lapply(.SD, mean), by = quadrant, .SDcols = x:y]
 
                 RP[, `:=`(prior.quadrant, (quadrant))]
@@ -164,7 +176,19 @@ NNS.part = function(x, y,
                 new.parts <- length(unique(PART$quadrant))
             }
 
+
             if(noise.reduction == "median") {
+                if(Voronoi) {
+                    if(l.PART > obs.req) {
+                        PART[obs.req.rows, {
+                            segments(min(x), median(y), max(x), median(y),
+                                     lty = 3)
+                            segments(median(x), min(y), median(x), max(y),
+                                     lty = 3)
+                        }, by = quadrant]
+                    }
+                }
+
                 RP <- PART[obs.req.rows, lapply(.SD, median), by = quadrant, .SDcols = x:y]
 
                 RP[, `:=`(prior.quadrant, (quadrant))]
@@ -185,6 +209,17 @@ NNS.part = function(x, y,
             }
 
             if (noise.reduction == "mode") {
+                if(Voronoi) {
+                    if(l.PART > obs.req) {
+                        PART[obs.req.rows, {
+                            segments(min(x), mode(y), max(x), mode(y),
+                                     lty = 3)
+                            segments(mode(x), min(y), mode(x), max(y),
+                                     lty = 3)
+                        }, by = quadrant]
+                    }
+                }
+
                 RP <- PART[obs.req.rows, lapply(.SD, mode), by = quadrant, .SDcols = x:y]
 
                 RP[, `:=`(prior.quadrant, (quadrant))]
@@ -214,13 +249,13 @@ NNS.part = function(x, y,
             RP[, `:=`(prior.quadrant = NULL)]
         }
         PART[, `:=`(counts = NULL, old.counts = NULL, q_new = NULL)]
-        DT <- PART[]
+
         RP <- setorder(RP[], quadrant)[]
         if (Voronoi) {
-            points(RP$x, RP$y, pch = 15, lwd = 2, col = "red")
             title(main = paste0("NNS Order = ", i), cex.main = 2)
+            points(RP$x, RP$y, pch = 15, lwd = 2, col = "red")
         }
-        return(list(order = i, dt = DT, regression.points = RP))
+        return(list(order = i, dt = PART[], regression.points = RP))
     }
 
     if(!is.null(type)) {
@@ -239,7 +274,26 @@ NNS.part = function(x, y,
             old.obs.req.rows <- PART[old.counts >= 1 * obs.req, which = TRUE]
 
             if(obs.req > 0 & length(obs.req.rows) < length(old.obs.req.rows)) break
-            if(noise.reduction == "mean" | noise.reduction == "off") {
+            if(noise.reduction == "off") {
+                RP <- PART[obs.req.rows, lapply(.SD, gravity), by = quadrant, .SDcols = x:y]
+
+                RP[, `:=`(prior.quadrant, (quadrant))]
+
+                PART[obs.req.rows, `:=`(prior.quadrant, (quadrant))]
+
+                old.parts <- length(unique(PART$quadrant))
+
+                PART[RP, on = .(quadrant), `:=`(q_new, {
+                    lox = x.x > i.x
+                    1L + lox
+                })]
+
+                PART[obs.req.rows, `:=`(quadrant, paste0(quadrant, q_new))]
+
+                new.parts <- length(unique(PART$quadrant))
+            }
+
+            if(noise.reduction == "mean") {
                 RP <- PART[obs.req.rows, lapply(.SD, mean), by = quadrant, .SDcols = x:y]
 
                 RP[, `:=`(prior.quadrant, (quadrant))]
@@ -307,7 +361,7 @@ NNS.part = function(x, y,
         }
 
         PART[, `:=`(counts = NULL, old.counts = NULL, q_new = NULL)]
-        DT <- PART[]
+
         RP <- setorder(RP[], quadrant)[]
 
         if(Voronoi) {
@@ -316,6 +370,6 @@ NNS.part = function(x, y,
             title(main = paste0("NNS Order = ", i), cex.main = 2)
         }
 
-        return(list(order = i, dt = DT, regression.points = RP))
+        return(list(order = i, dt = PART[], regression.points = RP))
     }
 }
