@@ -35,8 +35,11 @@ NNS.SSD <- function(x, y){
     legend("topleft", c("X", "Y"), lwd = 10, col = c("red", "blue"))
 
 
-    ifelse(!x.ssd.y & min(x) >= min(y) & mean(x) >= mean(y) & !identical(LPM_x_sort, LPM_y_sort), "X SSD Y",
-            ifelse (!y.ssd.x & min(y) >= min(x) & mean(y) >= mean(x) & !identical(LPM_x_sort, LPM_y_sort), "Y SSD X", "NO SSD EXISTS"))
+    ifelse(!x.ssd.y & min(x) >= min(y) & mean(x) >= mean(y) & !identical(LPM_x_sort, LPM_y_sort),
+           "X SSD Y",
+            ifelse (!y.ssd.x & min(y) >= min(x) & mean(y) >= mean(x) & !identical(LPM_x_sort, LPM_y_sort),
+                    "Y SSD X",
+                    "NO SSD EXISTS"))
 
 }
 
